{% extends 'layout.html' %}
{% block title %}Posts {{this_page_num}}{% endblock %}
{% block content %}
{% include 'postlist-pager.html' %}
<style type="text/css">
.toc-wrap { display: none; } 

</style>
<div id="postlist_wrap">
{% for post in posts %}
<div class="list-post">
    <h3>
        <a href="{{post.url}}">{{post.title}}</a> 
        <span class="post-date">{{post.mdate_string}}</span>
    </h3>
    <div class="clear"></div>
    <div>
        <div class="clear"></div> 
        {% if post.tags %}
            <div class="post-tags">
            {% for tag in post.tags %}
                <a class="tag"
                    href="/{{conf.search_tpl}}?t={{tag}}">{{tag}}
                    <span class="fontawesome-tag"></span></a>
            {% endfor %}
                <div class="clear"></div>
            </div>
        {% endif %}

        {% if post_type == 'full' %}
            {{post.target_text}}
        {% elif post_type == 'preview' %}
            <div class="htmltruncate-md">
                {{post.target_text}}
                <div class="htmltruncate-bottom"></div>
            </div>
            <a href="{{post.url}}" class="btn btn-default">...</a>
        {% else %}
            {{post.blurb}}
            <a href="{{post.url}}" class="btn">Read more</a>
        {% endif %}
        {% if sopt.disqus_shortname %}
        <div><a href="{{post.url}}#comments">Comments</a></div>
        {% endif %}
    </div>
</div>
{% endfor %}
</div>

{% include 'postlist-pager.html' %}
{% endblock %}

