<div id="footer">
    {{conf.style_footer}}
    <div class="container" style="text-align: center;">
        <div>
        <p class="text-muted credit">&copy; 2016 {{conf.site.title}}
        &mdash; powered by <a href="http://pykwiki.nullism.com">PyKwiki</a>
        </p>
        </div>

        {% if sopt.github_username and sopt.github_repo %}
        <div class="social-div">
            <a href="https://github.com/{{sopt.github_username}}/{{sopt.github_repo}}"
                class="icon-link"><b class="big-icon fontawesome-github"></b> github</a>
        </div>
        {% endif %}

        {% if sopt.facebook_appid and sopt.facebook_href %}
        <div id="fb-root"></div>
        <script>(function(d, s, id) {
            var js, fjs = d.getElementsByTagName(s)[0];
            if (d.getElementById(id)) return;
            js = d.createElement(s); js.id = id;
            js.src = "//connect.facebook.net/en_US/all.js#xfbml=1&appId={{sopt.facebook_appid}}";
            fjs.parentNode.insertBefore(js, fjs);
            }(document, 'script', 'facebook-jssdk'));</script>
        <div class="fb-like social-div" data-href="{{sopt.facebook_href}}" 
            style="margin-left: 10px;" data-width="400" data-colorscheme="light" 
            data-layout="button_count" data-action="like" data-show-faces="true" data-send="false">
        </div>
        {% endif %}

        {% if sopt.twitter_name %}
        <div class="social-div">
        <a href="https://twitter.com/{{sopt.twitter_name}}" class="icon-link" data-show-count="false"><b class="big-icon fontawesome-twitter"></b>Follow @{{sopt.twitter_name}}</a>
    <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';
                    if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';
                    fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');
            </script>
        </div>
        {% endif %}


        <div class="social-div">
            <a href="{{conf.web_prefix}}/{{conf.rss_tpl}}"
                class="icon-link"><b class="big-icon fontawesome-rss"></b>RSS</a>
        </div>

        <div class="clear"></div>
    </div>
</div>
